# Translating GatherUp

My hope is to get good coverage of major languages with the translations of the instructions (and in future the Question UI too), so that the tool is easy to use and accessible for people all over the globe.  This may be another aspect where this project is "over-engineered", but it seemed a nice goal to try.

The initial translations are done with Google Translate (so please accept my apologies for any inaccuracies!)

I don't anticipate translating into a huge number of languages, but if you would like to help with a particular language then please get in touch by raising an Issue.

[This link](https://github.com/nmstoker/gatherup/labels/translation) will show all issues tagged with the label "**translation**"

As my own spoken language skills are fairly limited I will need to rely on Google Translate and anyone who'll help.  If translating the instructions is too much, it would still be helpful to confirm translations proposed by others or even just to flag minor errors. The priority is to get the basic on-screen instructions translated first and then in time, if there is demand, I will explore UI translation options.